/****************************************************************************
** Meta object code from reading C++ file 'UIMachine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/runtime/UIMachine.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIMachine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9UIMachineE_t {};
} // unnamed namespace

template <> constexpr inline auto UIMachine::qt_create_metaobjectdata<qt_meta_tag_ZN9UIMachineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIMachine",
        "sigInitialized",
        "",
        "sigRequestAsyncVisualStateChange",
        "UIVisualStateType",
        "enmVisualStateType",
        "sigAdditionsStateChange",
        "sigAdditionsStateActualChange",
        "sigAudioAdapterChange",
        "sigClipboardModeChange",
        "KClipboardMode",
        "enmMode",
        "sigCPUExecutionCapChange",
        "sigDnDModeChange",
        "KDnDMode",
        "sigGuestMonitorChange",
        "KGuestMonitorChangedEventType",
        "emnChangeType",
        "uScreenId",
        "QRect",
        "screenGeo",
        "sigMachineStateChange",
        "sigMediumChange",
        "CMediumAttachment",
        "comMediumAttachment",
        "sigNetworkAdapterChange",
        "CNetworkAdapter",
        "comNetworkAdapter",
        "sigRecordingChange",
        "sigSharedFolderChange",
        "sigStorageDeviceChange",
        "comAttachment",
        "fRemoved",
        "fSilent",
        "sigUSBControllerChange",
        "sigUSBDeviceStateChange",
        "CUSBDevice",
        "comDevice",
        "fAttached",
        "CVirtualBoxErrorInfo",
        "comError",
        "sigVRDEChange",
        "sigRuntimeError",
        "bIsFatal",
        "strErrorId",
        "strMessage",
        "sigKeyboardLedsChange",
        "sigKeyboardStateChange",
        "iState",
        "sigMousePointerShapeChange",
        "sigMouseCapabilityChange",
        "sigCursorPositionChange",
        "sigMouseStateChange",
        "sigHostScreenCountChange",
        "sigHostScreenGeometryChange",
        "sigHostScreenAvailableAreaChange",
        "sltInstallGuestAdditionsFrom",
        "strSource",
        "sltMountDVDAdHoc",
        "setKeyboardState",
        "iKeyboardState",
        "setMouseState",
        "iMouseState",
        "closeRuntimeUI",
        "sltChangeVisualState",
        "sltHandleAdditionsActualChange",
        "sltHandleAudioAdapterChange",
        "sltHandleRecordingChange",
        "sltHandleStorageDeviceChange",
        "sltHandleVRDEChange",
        "sltHandleHostScreenCountChange",
        "sltHandleHostScreenGeometryChange",
        "sltHandleHostScreenAvailableAreaChange",
        "sltHandleGuestMonitorChange",
        "enmChangeType",
        "sltHandleKeyboardLedsChange",
        "fNumLock",
        "fCapsLock",
        "fScrollLock",
        "sltHidLedsSyncStateChanged",
        "fEnabled",
        "sltMousePointerShapeChange",
        "UIMousePointerShapeData",
        "shapeData",
        "sltMouseCapabilityChange",
        "fSupportsAbsolute",
        "fSupportsRelative",
        "fSupportsTouchScreen",
        "fSupportsTouchPad",
        "fNeedsHostCursor",
        "sltCursorPositionChange",
        "fContainsData",
        "uX",
        "uY"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigInitialized'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRequestAsyncVisualStateChange'
        QtMocHelpers::SignalData<void(UIVisualStateType)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'sigAdditionsStateChange'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigAdditionsStateActualChange'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigAudioAdapterChange'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigClipboardModeChange'
        QtMocHelpers::SignalData<void(KClipboardMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'sigCPUExecutionCapChange'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigDnDModeChange'
        QtMocHelpers::SignalData<void(KDnDMode)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 11 },
        }}),
        // Signal 'sigGuestMonitorChange'
        QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::ULong, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Signal 'sigMachineStateChange'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigMediumChange'
        QtMocHelpers::SignalData<void(const CMediumAttachment &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'sigNetworkAdapterChange'
        QtMocHelpers::SignalData<void(const CNetworkAdapter &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'sigRecordingChange'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigSharedFolderChange'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigStorageDeviceChange'
        QtMocHelpers::SignalData<void(const CMediumAttachment &, bool, bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 31 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Signal 'sigUSBControllerChange'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigUSBDeviceStateChange'
        QtMocHelpers::SignalData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::Bool, 38 }, { 0x80000000 | 39, 40 },
        }}),
        // Signal 'sigVRDEChange'
        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRuntimeError'
        QtMocHelpers::SignalData<void(bool, const QString &, const QString &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 }, { QMetaType::QString, 44 }, { QMetaType::QString, 45 },
        }}),
        // Signal 'sigKeyboardLedsChange'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigKeyboardStateChange'
        QtMocHelpers::SignalData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Signal 'sigMousePointerShapeChange'
        QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigMouseCapabilityChange'
        QtMocHelpers::SignalData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCursorPositionChange'
        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigMouseStateChange'
        QtMocHelpers::SignalData<void(int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Signal 'sigHostScreenCountChange'
        QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigHostScreenGeometryChange'
        QtMocHelpers::SignalData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigHostScreenAvailableAreaChange'
        QtMocHelpers::SignalData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltInstallGuestAdditionsFrom'
        QtMocHelpers::SlotData<void(const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 },
        }}),
        // Slot 'sltMountDVDAdHoc'
        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 },
        }}),
        // Slot 'setKeyboardState'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 60 },
        }}),
        // Slot 'setMouseState'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 62 },
        }}),
        // Slot 'closeRuntimeUI'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltChangeVisualState'
        QtMocHelpers::SlotData<void(UIVisualStateType)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'sltHandleAdditionsActualChange'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleAudioAdapterChange'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleRecordingChange'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleStorageDeviceChange'
        QtMocHelpers::SlotData<void(const CMediumAttachment &, bool, bool)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 31 }, { QMetaType::Bool, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'sltHandleVRDEChange'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleHostScreenCountChange'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleHostScreenGeometryChange'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleHostScreenAvailableAreaChange'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltHandleGuestMonitorChange'
        QtMocHelpers::SlotData<void(KGuestMonitorChangedEventType, ulong, QRect)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 74 }, { QMetaType::ULong, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'sltHandleKeyboardLedsChange'
        QtMocHelpers::SlotData<void(bool, bool, bool)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 76 }, { QMetaType::Bool, 77 }, { QMetaType::Bool, 78 },
        }}),
        // Slot 'sltHidLedsSyncStateChanged'
        QtMocHelpers::SlotData<void(bool)>(79, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 80 },
        }}),
        // Slot 'sltMousePointerShapeChange'
        QtMocHelpers::SlotData<void(const UIMousePointerShapeData &)>(81, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 82, 83 },
        }}),
        // Slot 'sltMouseCapabilityChange'
        QtMocHelpers::SlotData<void(bool, bool, bool, bool, bool)>(84, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 85 }, { QMetaType::Bool, 86 }, { QMetaType::Bool, 87 }, { QMetaType::Bool, 88 },
            { QMetaType::Bool, 89 },
        }}),
        // Slot 'sltCursorPositionChange'
        QtMocHelpers::SlotData<void(bool, unsigned long, unsigned long)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 91 }, { QMetaType::ULong, 92 }, { QMetaType::ULong, 93 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIMachine, qt_meta_tag_ZN9UIMachineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIMachine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UIMachineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UIMachineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9UIMachineE_t>.metaTypes,
    nullptr
} };

void UIMachine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIMachine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigInitialized(); break;
        case 1: _t->sigRequestAsyncVisualStateChange((*reinterpret_cast<std::add_pointer_t<UIVisualStateType>>(_a[1]))); break;
        case 2: _t->sigAdditionsStateChange(); break;
        case 3: _t->sigAdditionsStateActualChange(); break;
        case 4: _t->sigAudioAdapterChange(); break;
        case 5: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
        case 6: _t->sigCPUExecutionCapChange(); break;
        case 7: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
        case 8: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
        case 9: _t->sigMachineStateChange(); break;
        case 10: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
        case 11: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
        case 12: _t->sigRecordingChange(); break;
        case 13: _t->sigSharedFolderChange(); break;
        case 14: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->sigUSBControllerChange(); break;
        case 16: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
        case 17: _t->sigVRDEChange(); break;
        case 18: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->sigKeyboardLedsChange(); break;
        case 20: _t->sigKeyboardStateChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->sigMousePointerShapeChange(); break;
        case 22: _t->sigMouseCapabilityChange(); break;
        case 23: _t->sigCursorPositionChange(); break;
        case 24: _t->sigMouseStateChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->sigHostScreenCountChange(); break;
        case 26: _t->sigHostScreenGeometryChange(); break;
        case 27: _t->sigHostScreenAvailableAreaChange(); break;
        case 28: _t->sltInstallGuestAdditionsFrom((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->sltMountDVDAdHoc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->setKeyboardState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->setMouseState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->closeRuntimeUI(); break;
        case 33: _t->sltChangeVisualState((*reinterpret_cast<std::add_pointer_t<UIVisualStateType>>(_a[1]))); break;
        case 34: _t->sltHandleAdditionsActualChange(); break;
        case 35: _t->sltHandleAudioAdapterChange(); break;
        case 36: _t->sltHandleRecordingChange(); break;
        case 37: _t->sltHandleStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 38: _t->sltHandleVRDEChange(); break;
        case 39: _t->sltHandleHostScreenCountChange(); break;
        case 40: _t->sltHandleHostScreenGeometryChange(); break;
        case 41: _t->sltHandleHostScreenAvailableAreaChange(); break;
        case 42: _t->sltHandleGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
        case 43: _t->sltHandleKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 44: _t->sltHidLedsSyncStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->sltMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
        case 46: _t->sltMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 47: _t->sltCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UIVisualStateType >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KClipboardMode >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDnDMode >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGuestMonitorChangedEventType >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UIVisualStateType >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGuestMonitorChangedEventType >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UIMousePointerShapeData >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigInitialized, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(UIVisualStateType )>(_a, &UIMachine::sigRequestAsyncVisualStateChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigAdditionsStateChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigAdditionsStateActualChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigAudioAdapterChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(KClipboardMode )>(_a, &UIMachine::sigClipboardModeChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigCPUExecutionCapChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(KDnDMode )>(_a, &UIMachine::sigDnDModeChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(KGuestMonitorChangedEventType , ulong , QRect )>(_a, &UIMachine::sigGuestMonitorChange, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigMachineStateChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(const CMediumAttachment & )>(_a, &UIMachine::sigMediumChange, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(const CNetworkAdapter & )>(_a, &UIMachine::sigNetworkAdapterChange, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigRecordingChange, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigSharedFolderChange, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(const CMediumAttachment & , bool , bool )>(_a, &UIMachine::sigStorageDeviceChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigUSBControllerChange, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(const CUSBDevice & , bool , const CVirtualBoxErrorInfo & )>(_a, &UIMachine::sigUSBDeviceStateChange, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigVRDEChange, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(bool , const QString & , const QString & )>(_a, &UIMachine::sigRuntimeError, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigKeyboardLedsChange, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(int )>(_a, &UIMachine::sigKeyboardStateChange, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigMousePointerShapeChange, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigMouseCapabilityChange, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigCursorPositionChange, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)(int )>(_a, &UIMachine::sigMouseStateChange, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigHostScreenCountChange, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigHostScreenGeometryChange, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIMachine::*)()>(_a, &UIMachine::sigHostScreenAvailableAreaChange, 27))
            return;
    }
}

const QMetaObject *UIMachine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIMachine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UIMachineE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UIMachine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void UIMachine::sigInitialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UIMachine::sigRequestAsyncVisualStateChange(UIVisualStateType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UIMachine::sigAdditionsStateChange()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UIMachine::sigAdditionsStateActualChange()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void UIMachine::sigAudioAdapterChange()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UIMachine::sigClipboardModeChange(KClipboardMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UIMachine::sigCPUExecutionCapChange()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void UIMachine::sigDnDModeChange(KDnDMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void UIMachine::sigGuestMonitorChange(KGuestMonitorChangedEventType _t1, ulong _t2, QRect _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void UIMachine::sigMachineStateChange()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void UIMachine::sigMediumChange(const CMediumAttachment & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void UIMachine::sigNetworkAdapterChange(const CNetworkAdapter & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void UIMachine::sigRecordingChange()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void UIMachine::sigSharedFolderChange()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void UIMachine::sigStorageDeviceChange(const CMediumAttachment & _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void UIMachine::sigUSBControllerChange()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void UIMachine::sigUSBDeviceStateChange(const CUSBDevice & _t1, bool _t2, const CVirtualBoxErrorInfo & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void UIMachine::sigVRDEChange()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void UIMachine::sigRuntimeError(bool _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2, _t3);
}

// SIGNAL 19
void UIMachine::sigKeyboardLedsChange()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void UIMachine::sigKeyboardStateChange(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void UIMachine::sigMousePointerShapeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void UIMachine::sigMouseCapabilityChange()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void UIMachine::sigCursorPositionChange()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void UIMachine::sigMouseStateChange(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void UIMachine::sigHostScreenCountChange()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void UIMachine::sigHostScreenGeometryChange()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void UIMachine::sigHostScreenAvailableAreaChange()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
